@@ -112,4 +112,7 @@ shadowUpdatePacked (ScreenPtr	    pScreen,
     }
 }
 
-shadowUpdateProc shadowUpdatePackedWeak(void) { return shadowUpdatePacked; }
+shadowUpdateProc
+shadowUpdatePackedWeak(void) {
+    return shadowUpdatePacked;
+}
